@@ -23,17 +23,13 @@ class BareMetalOperations:
     SHORT_TIMEOUT = 600
 
     @typechecked
-    def __init__(self, user: str):
+    def __init__(self, user: str = None):
         self._environment_variables_dict = environment_variables.environment_variables_dict
-        self._user = user
         self._ocp_env_flavor = self._environment_variables_dict.get('ocp_env_flavor', '')
         self._create_pod_ci_cmd = self._environment_variables_dict.get('create_pod_ci_cmd', '')
-        self._provision_kubeadmin_password_path = self._environment_variables_dict.get('provision_kubeadmin_password_path', '')
-        self._provision_kubeconfig_path = self._environment_variables_dict.get('provision_kubeconfig_path', '')
-        self._provision_installer_path = self._environment_variables_dict.get('provision_installer_path', '')
-        self._provision_installer_cmd = self._environment_variables_dict.get('provision_installer_cmd', '')
-        self._provision_installer_log = self._environment_variables_dict.get('provision_installer_log', '')
         self._install_ocp_version = self._environment_variables_dict.get('install_ocp_version', '')
+        self._ocp_build = self._environment_variables_dict.get('ocp_build', '')
+        self._installer_var_path = self._environment_variables_dict.get('installer_var_path', '')
         self._cluster_type = self._environment_variables_dict.get('cluster_type', '')
         self._expected_nodes = self._environment_variables_dict.get('expected_nodes', '')
         if self._expected_nodes:
@@ -41,21 +37,32 @@ class BareMetalOperations:
             self._expected_nodes = ast.literal_eval(self._expected_nodes)
         self._ocp_version_build = self._environment_variables_dict.get('ocp_version_build', '')
         self._num_odf_disks = int(self._environment_variables_dict.get('num_odf_disk', 1))
-        self._provision_ip = self._environment_variables_dict.get('provision_ip', '')
-        self._provision_port = int(self._environment_variables_dict.get('provision_port', ''))
-        self._provision_timeout = int(self._environment_variables_dict.get('provision_timeout', ''))
-        self._container_private_key_path = self._environment_variables_dict.get('container_private_key_path', '')
-        self._connection_data = ConnectionData(host_name=self._provision_ip,
-                                                user_name=self._user,
-                                                port=self._provision_port,
-                                                timeout=self._provision_timeout,
-                                                ssh_key=self._container_private_key_path)
-        self._remote_ssh = RemoteSsh(self._connection_data)
-        if self._environment_variables_dict.get('github_repository_short', ''):
-            self._github_operations = GitHubOperations()
         self._ssh = SSH()
         self._cli = self._environment_variables_dict.get('cli', '')
         self._upgrade_ocp_version = self._environment_variables_dict.get('upgrade_ocp_version', '')
+        self._upgrade_channel = self._environment_variables_dict.get('upgrade_channel', '')
+        self._timeout = int(self._environment_variables_dict.get('timeout', ''))
+        self._must_gather_log = self._environment_variables_dict.get('must_gather_log', '')
+        self._run_artifacts_path = self._environment_variables_dict.get('run_artifacts_path', '')
+        if user:
+            self._user = user
+            self._provision_kubeadmin_password_path = self._environment_variables_dict.get('provision_kubeadmin_password_path', '')
+            self._provision_kubeconfig_path = self._environment_variables_dict.get('provision_kubeconfig_path', '')
+            self._provision_installer_path = self._environment_variables_dict.get('provision_installer_path', '')
+            self._provision_installer_cmd = self._environment_variables_dict.get('provision_installer_cmd', '')
+            self._provision_installer_log = self._environment_variables_dict.get('provision_installer_log', '')
+            self._provision_ip = self._environment_variables_dict.get('provision_ip', '')
+            self._provision_port = int(self._environment_variables_dict.get('provision_port', ''))
+            self._provision_timeout = int(self._environment_variables_dict.get('provision_timeout', ''))
+            self._container_private_key_path = self._environment_variables_dict.get('container_private_key_path', '')
+            self._connection_data = ConnectionData(host_name=self._provision_ip,
+                                                    user_name=self._user,
+                                                    port=self._provision_port,
+                                                    timeout=self._provision_timeout,
+                                                    ssh_key=self._container_private_key_path)
+            self._remote_ssh = RemoteSsh(self._connection_data)
+            if self._environment_variables_dict.get('github_repository_short', ''):
+                self._github_operations = GitHubOperations()
 
     def _get_kubeadmin_password(self):
         """
@@ -102,14 +109,17 @@ class BareMetalOperations:
         current_wait_time = 0
         logger.info(f'Waiting until the upgrade to version {self._upgrade_ocp_version} starts...')
         oc.wait_for_ocp_upgrade_start(upgrade_version=self._upgrade_ocp_version)
-        while self._provision_timeout <= 0 or current_wait_time <= self._provision_timeout and oc.upgrade_in_progress():
+        while (self._timeout <= 0 or current_wait_time <= self._timeout) and oc.upgrade_in_progress():
             logger.info(f'Waiting till OCP upgrade complete, waiting {int(current_wait_time / 60)} minutes')
             # sleep for x seconds
             time.sleep(sleep_time)
             current_wait_time += sleep_time
-        if f'Cluster version is {self._upgrade_ocp_version}' == oc.get_cluster_status():
+        if oc.get_upgrade_version() == self._upgrade_ocp_version:
+            logger.info(f"OCP successfully upgraded to {oc.get_upgrade_version()}")
             return True
         else:
+            if self._must_gather_log:
+                oc.generate_ocp_must_gather(destination_path=self._run_artifacts_path)
             raise OCPUpgradeFailed(status=oc.get_cluster_status())
 
     def _install_ocp_cmd(self):
@@ -194,14 +204,22 @@ class BareMetalOperations:
         if self.LATEST in self._install_ocp_version:
             self._install_ocp_version = self._get_installation_version()
         openshift_version_data = self._install_ocp_version.split('.')
-        self._remote_ssh.replace_parameter(remote_path='/root/jetlag/ansible/vars',
+        self._remote_ssh.replace_parameter(remote_path=self._installer_var_path,
                                             file_name=file_name,
                                             parameter='ocp_release_image:',
                                             value=fr'quay.io\/openshift-release-dev\/ocp-release:{self._install_ocp_version}-x86_64')
-        self._remote_ssh.replace_parameter(remote_path='/root/jetlag/ansible/vars',
+        self._remote_ssh.replace_parameter(remote_path=self._installer_var_path,
                                             file_name=file_name,
                                             parameter='openshift_version:',
                                             value=f'"{openshift_version_data[0]}.{openshift_version_data[1]}"')
+        self._remote_ssh.replace_parameter(remote_path=self._installer_var_path,
+                                            file_name=file_name,
+                                            parameter='ocp_version:',
+                                            value=f'"{self._install_ocp_version}"')
+        self._remote_ssh.replace_parameter(remote_path=self._installer_var_path,
+                                            file_name=file_name,
+                                            parameter='ocp_build:',
+                                            value=f'"{self._ocp_build}"')
 
     def update_provision_config(self):
         """
@@ -251,7 +269,7 @@ class BareMetalOperations:
         logger.info(f'Starting OCP upgrade, Start time: {datetime.now().strftime(datetime_format)}')
         logger.info(f'Stop OCP healthcheck')
         oc.healthcheck(action='stop')
-        oc.upgrade_ocp(upgrade_ocp_version=self._upgrade_ocp_version)
+        oc.upgrade_ocp(upgrade_ocp_version=self._upgrade_ocp_version, upgrade_channel=self._upgrade_channel)
         self.verify_upgrade_complete(oc=oc)
         logger.info(f'Resume OCP healthcheck')
         oc.healthcheck(action='resume')
@@ -270,24 +288,34 @@ class BareMetalOperations:
         else:
             return True
 
-    def is_cluster_upgraded(self, oc: OC, cnv_version: str, odf_version: str, lso_version: str):
+    def is_cluster_upgraded(self, oc: OC, cnv_version: str = None, odf_version: str = None,
+                            lso_version: str = None) -> bool:
         """
-        This method checks if cluster/operators upgraded successfully
-        @param oc:
-        @param cnv_version:
-        @param odf_version:
-        @param lso_version:
-        @return:
+        Checks if the cluster and the specified operators were successfully upgraded.
+
+        :param oc: OC client instance
+        :param cnv_version: (Optional) Target CNV operator version
+        :param odf_version: (Optional) Target ODF operator version
+        :param lso_version: (Optional) Target LSO operator version
+        :return: True if the upgrade (cluster + specified operators) is successful, otherwise False
         """
-        # check cluster version upgrade
-        if oc.get_upgrade_version() == self._upgrade_ocp_version:
-            lso_upgraded = oc.wait_for_operator_installation(operator='lso', version=lso_version, namespace='openshift-local-storage')
-            odf_upgraded = oc.wait_for_operator_installation(operator='odf', version=odf_version, namespace='openshift-storage')
-            cnv_upgraded = oc.wait_for_operator_installation(operator='cnv', version=cnv_version, namespace='openshift-cnv')
-            # check operators versions upgrade
-            if cnv_upgraded and lso_upgraded and odf_upgraded:
-                return True
-        return False
+        if oc.get_upgrade_version() != self._upgrade_ocp_version:
+            return False
+
+        # Operator details mapping: short_key -> (version, namespace, operator_name_prefix)
+        operators_to_check = {
+            "cnv": (cnv_version, "openshift-cnv", "kubevirt-hyperconverged-operator"),
+            "odf": (odf_version, "openshift-storage", "odf-operator"),
+            "lso": (lso_version, "openshift-local-storage", "local-storage-operator"),
+        }
+
+        upgrade_checks = [
+            oc.wait_for_operator_installation(operator_name=operator_name, version=ver, namespace=ns)
+            for _, (ver, ns, operator_name) in operators_to_check.items()
+            if ver  # only include if a version was specified
+        ]
+
+        return all(upgrade_checks) if upgrade_checks else True
 
     @logger_time_stamp
     def verify_upgrade_complete(self, oc: OC):
@@ -301,13 +329,16 @@ class BareMetalOperations:
         raise OCPUpgradeFailed(status=oc.get_cluster_status())
 
     @logger_time_stamp
-    def oc_login(self):
+    def get_oc(self, kubeadmin_password: str = ''):
         """
         This method login to the cluster with new credentials
+        :param kubeadmin_password, default empty
         :return:
         """
-        oc = OC(kubeadmin_password=self._get_kubeadmin_password())
-        oc.login()
+        if kubeadmin_password:
+            oc = OC(kubeadmin_password=kubeadmin_password)
+        else:
+            oc = OC(kubeadmin_password=self._get_kubeadmin_password())
         return oc
 
     @staticmethod
